@@ -18,7 +18,7 @@ class PWM:
     # Delay between check for scucessful PWM export on open (100ms)
     PWM_STAT_DELAY = 0.1
 
-    def __init__(self, chip, channel):
+    def __init__(self, chip, channel, destroy_on_exit: bool = True):
         """Instantiate a PWM object and open the sysfs PWM corresponding to the
         specified chip and channel.
         Args:
@@ -32,6 +32,7 @@ class PWM:
             LookupError: if PWM chip does not exist.
             TimeoutError: if waiting for PWM export times out.
         """
+        self._destroy_on_exit = destroy_on_exit
         self._chip = None
         self._channel = None
         self._path = None
@@ -47,6 +48,19 @@ class PWM:
     def __exit__(self, t, value, traceback):
         self.close()
 
+    @classmethod
+    def is_pwm_chip_available(cls, chip: int) -> bool:
+        """Determine if PWM chip interface is available
+
+        Args:
+            chip (int): PWM chip
+
+        Returns:
+            bool: Exists
+        """
+        chip_path = f'/sys/class/pwm/pwmchip{chip}'
+        return os.path.isdir(chip_path)
+
     def _open(self, chip, channel):
         if not isinstance(chip, int):
             raise TypeError("Invalid chip type, should be integer.")
@@ -101,7 +115,7 @@ class PWM:
     def close(self):
         """Close the PWM."""
 
-        if self._channel is not None:
+        if self._destroy_on_exit and self._channel is not None:
             # Unexport the PWM channel
             try:
                 unexport_fd = os.open("/sys/class/pwm/pwmchip{}/unexport".format(self._chip), os.O_WRONLY)
